Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ConnectionPoolConfig ¶ added in v1.4.1
type FailureDomainConfiguration ¶
type FailureDomainConfiguration uint64
FailureDomainConfiguration is the configuration format for failure-domain (just an integer)
type InitConfiguration ¶
type InitConfiguration struct {
// Address is the bind address to use for this node.
Address string `yaml:"Address"`
// Cluster is a list of "host:port" addresses of existing cluster nodes.
Cluster []string `yaml:"Cluster"`
}
InitConfiguration is the configuration format for init.yaml
type Server ¶
type Server struct {
// contains filtered or unexported fields
}
Server is the main k8s-dqlite server.
func New ¶
func New( dir string, listen string, enableTLS bool, diskMode bool, clientSessionCacheSize uint, minTLSVersion string, watchAvailableStorageInterval time.Duration, watchAvailableStorageMinBytes uint64, lowAvailableStorageAction string, connectionPoolConfig *ConnectionPoolConfig, watchQueryTimeout time.Duration, watchProgressNotifyInterval time.Duration, ) (*Server, error)
New creates a new instance of Server based on configuration.
func (*Server) MustStop ¶
func (s *Server) MustStop() <-chan struct{}
MustStop returns a channel that can be used to check whether the server must stop.
type ServerConfig ¶ added in v1.4.1
type TuningConfiguration ¶
type TuningConfiguration struct {
// Snapshot is tuning for the raft snapshot parameters.
// If non-nil, it is set with app.WithSnapshotParams() when starting dqlite.
Snapshot *struct {
Threshold uint64 `yaml:"threshold"`
Trailing uint64 `yaml:"trailing"`
Strategy string `yaml:"strategy"`
} `yaml:"snapshot"`
// NetworkLatency is the average one-way network latency between dqlite nodes.
// If non-nil, it is passed as app.WithNetworkLatency() when starting dqlite.
NetworkLatency *time.Duration `yaml:"network-latency"`
// K8sDqliteCompactInterval is the interval between k8s-dqlite database compaction operations.
K8sDqliteCompactInterval *time.Duration `yaml:"kine-compact-interval"`
// K8sDqlitePollInterval is the k8s-dqite poll interval.
K8sDqlitePollInterval *time.Duration `yaml:"kine-poll-interval"`
}
TuningConfiguration is configuration for tuning dqlite and k8s-dqlite parameters
type UpdateConfiguration ¶
type UpdateConfiguration struct {
// Address is the new bind address to use for this node.
Address string `yaml:"Address"`
}
UpdateConfiguration is the configuration format for update.yaml
Click to show internal directories.
Click to hide internal directories.